@@ -59,7 +59,7 @@ def get_all_marketing_emails(api_key, app_private_token):
                 print(resp)
                 time.sleep(10)
             else:
-                prefect.context.logger.error("Failed")
-                prefect.context.logger.error(e)
-                prefect.context.logger.error(resp)
+                prefect.get_run_logger().error("Failed")
+                prefect.get_run_logger().error(e)
+                prefect.get_run_logger().error(resp)
                 raise e
